@@ -18,9 +18,9 @@ __PACKAGE__->add_columns(
   "entered",
   {
     data_type     => "timestamp",
-    default_value => \"current_timestamp",
+    default_value => \"LOCALTIMESTAMP",
     is_nullable   => 1,
-    original      => { default_value => \"now()" },
+    original      => { default_value => \"LOCALTIMESTAMP" },
   },
   "started",
   { data_type => "timestamp", is_nullable => 1 },
